#!/bin/bash
#
# orakafka.sh
#
# Copyright (c) 2019, 2020, Oracle and/or its affiliates. All rights reserved.
#
#    NAME
#      orakafka.sh
#
#    DESCRIPTION
#      Top level CLI for Oracle SQL Access to Kafka.
#
#    NOTES
#      <other useful comments, qualifications, etc.>
#

function usage {
  echo "Usage: ./orakafka.sh COMMAND <args>"
  echo "where COMMAND is one of:"
  echo "  setup_all           - End-to-end setup of a Kafka cluster configuration"
  echo "                        directory and ORA_KAFKA package for a user"
  echo "  set_java_home       - Configures JAVA_HOME to be used by all"
  echo "                        Oracle SQL Access to Kafka scripts that use Java"
  echo "  add_cluster         - Creates a filesystem cluster configuration directory"
  echo "                        and generates DDL to create cluster configuration"
  echo "                        database directory"
  echo "  remove_cluster      - Removes the filesystem cluster configuration directory"
  echo "                        and generates DDL to remove cluster configuration "
  echo "                        database directory"
  echo "  test_cluster        - Tests the cluster configuration against a given"
  echo "                        Kafka cluster"
  echo "  list_clusters       - Lists all clusters configured for Oracle SQL"
  echo "                        Access to Kafka"
  echo "  install             - Generates DDL to install ORA_KAFKA package in the"
  echo "                        user schema and create database directories"
  echo "  uninstall           - Generates DDL to uninstall ORA_KAFKA package from"
  echo "                        user schema and remove database directories"
  echo "  adduser_cluster     - Grants permissions on specified Kafka cluster"
  echo "                        to a specified user"
  echo "  removeuser_cluster  - Revokes permissions on specified Kafka cluster"
  echo "                        from a specified user"
  echo "  test_views          - End-to-end test for Oracle SQL Access to Kafka"
  echo "  version             - Shows version info for Oracle SQL access to"
  echo "                        Kafka"
  echo "  verify_install      - Verifies the Oracle SQL Access to Kafka kit "
  echo "                        install"
  echo "Use -h option with each command for detailed help."
  exit 1
}

if [[ $# -eq 0 ]]; then
  usage
fi

source $(dirname $0)/scripts/config_util.sh

COMMAND="$1"

case $COMMAND in
 set_java_home)
  SCRIPT=set_java_home.sh
  ;;
 add_cluster)
  SCRIPT=add_cluster.sh
  ;;
 remove_cluster)
  SCRIPT=remove_cluster.sh
  ;;
 install)
  SCRIPT=install.sh
  ;;
 uninstall)
  SCRIPT=uninstall.sh
  ;;
 test_cluster)
  SCRIPT=test_cluster.sh
  ;;
 test_views)
  SCRIPT=test_views.sh
  ;;
 list_clusters)
  SCRIPT=list_clusters.sh
  ;;
 setup_all)
  SCRIPT=setup_all.sh
  ;;
 adduser_cluster)
  SCRIPT=adduser_cluster.sh
  ;;
 removeuser_cluster)
  SCRIPT=removeuser_cluster.sh
  ;;
 version)
  if [[ "$2" = "-h" ]]; then
    echo "Usage: ./orakafka.sh version"
    exit 0
  fi
  echo 'Oracle SQL Access to Kafka Release: '$(cat "${ORAKAFKA_HOME}/kit_version.txt") 
  exit 0
  ;;
 verify_install)
  SCRIPT=verify_install.sh
  ;;
 *) echo "Invalid command."
    usage
    ;;
esac
shift

CURRENT_TIME=$(date "+%Y.%m.%d-%H.%M.%S")
${ORAKAFKA_HOME}/bin/scripts/${SCRIPT} "$@" 2>&1 | tee ${APP_DATA_LOGS_DIR}/${COMMAND}.log."$CURRENT_TIME"

if [ "$1" != "-h" ] && [ ! -z "$1" ] || 
   [ "$COMMAND" = "list_clusters" ]  || 
   [ "$COMMAND" = "verify_install" ] 
then
 echo -e "\nThe above information is written to ${APP_DATA_LOGS_DIR}/${COMMAND}.log.$CURRENT_TIME\n"
fi
